@@ -15,6 +15,8 @@
 #' @param use.hinges logical Flag indicating whether to insert "hinges" into the
 #'   spectral data before integration so as to reduce interpolation errors at
 #'   the boundaries of the wavebands.
+#' @param naming character one of "long", "default", "short" or "none". Used to
+#'   select the type of names to assign to returned value.
 #' @param ... other arguments (possibly used by derived methods).
 #'
 #' @return A named \code{numeric} vector in the case of methods for individual
@@ -69,11 +71,19 @@ absorbance.default <- function(spct, w.band, quantity, wb.trim, use.hinges, ...)
 #' @export
 #'
 absorbance.filter_spct <-
-  function(spct, w.band=NULL, quantity="average",
-           wb.trim = getOption("photobiology.waveband.trim", default =TRUE),
-           use.hinges=getOption("photobiology.use.hinges", default=NULL), ...) {
-    absorbance_spct(spct = spct, w.band = w.band, quantity = quantity, wb.trim = wb.trim,
-                    use.hinges = use.hinges)
+  function(spct,
+           w.band = NULL,
+           quantity = "average",
+           wb.trim = getOption("photobiology.waveband.trim", default = TRUE),
+           use.hinges = NULL,
+           naming = "default",
+           ...) {
+    absorbance_spct(spct = spct,
+                    w.band = w.band,
+                    quantity = quantity,
+                    wb.trim = wb.trim,
+                    use.hinges = use.hinges,
+                    naming = naming)
   }
 
 #' @describeIn absorbance Specialization for object spectra
@@ -81,11 +91,20 @@ absorbance.filter_spct <-
 #' @export
 #'
 absorbance.object_spct <-
-  function(spct, w.band=NULL, quantity="average",
-           wb.trim = getOption("photobiology.waveband.trim", default =TRUE),
-           use.hinges=getOption("photobiology.use.hinges", default=NULL), ...) {
+  function(spct,
+           w.band = NULL,
+           quantity = "average",
+           wb.trim = getOption("photobiology.waveband.trim", default = TRUE),
+           use.hinges = NULL,
+           naming = "default",
+           ...) {
     spct <- as.filter_spct(spct)
-    absorbance_spct(spct, w.band = w.band, quantity = quantity, wb.trim = wb.trim, use.hinges = use.hinges)
+    absorbance_spct(spct,
+                    w.band = w.band,
+                    quantity = quantity,
+                    wb.trim = wb.trim,
+                    use.hinges = use.hinges,
+                    naming = naming)
   }
 
 #' Calculate absorbance from spectral absorbance.
@@ -104,10 +123,29 @@ absorbance.object_spct <-
 #'   are trimmed or ignored
 #' @param use.hinges logical Flag indicating whether to use hinges to reduce
 #'   interpolation errors
+#' @param naming character one of "long", "default", "short" or "none". Used to
+#'   select the type of names to assign to returned value.
 #' @keywords internal
 #'
 absorbance_spct <-
-  function(spct, w.band, quantity, wb.trim, use.hinges) {
+  function(spct,
+           w.band,
+           quantity,
+           wb.trim,
+           use.hinges,
+           naming) {
+    summary.name <-
+      switch(quantity,
+             total = "A",
+             average = "A(wl)",
+             mean = "A(wl)",
+             contribution = "A/Atot",
+             contribution.pc = "A/Atot[%]",
+             relative = "A/Asum",
+             relative.pc = "A/Asum[%]",
+             stop("Unrecognized 'quantity' : \"", quantity, "\"")
+      )
+    # we look for multiple spectra and return with a warning
     num.spectra <- getMultipleWl(spct)
     if (num.spectra != 1) {
       warning("Skipping absorbance calculation as object contains ",
@@ -115,7 +153,8 @@ absorbance_spct <-
       return(NA_real_)
     }
     if (is_normalized(spct)) {
-      warning("The spectral data has been normalized, making impossible to calculate absorbance")
+      warning("The spectral data has been normalized,",
+              "making impossible to calculate absorbance")
       return(NA_real_)
     }
     if (is_scaled(spct)) {
@@ -123,73 +162,66 @@ absorbance_spct <-
     }
     spct <- T2A(spct, action = "replace", byref = FALSE)
     spct <- spct[ , c("w.length", "A")]
-    # if the waveband is undefined then use all data
+
     if (length(w.band) == 0) {
+      # whole range of spectrum
       w.band <- waveband(spct)
     }
     if (is.numeric(w.band)) {
       w.band <- waveband(w.band)
     }
-
     if (is.waveband(w.band)) {
       # if the argument is a single w.band, we enclose it in a list
-      # so that the for loop works as expected.This is a bit of a
-      # kludge but let's us avoid treating it as a special case
+      # so that it can be handled below as a normal case.
       w.band <- list(w.band)
     }
-    w.band <- trim_waveband(w.band=w.band, range=spct, trim=wb.trim)
+    # we trim the wavebands so that they are within the range of spct
+    w.band <- trim_waveband(w.band = w.band, range = spct, trim = wb.trim)
+    # if the elements of the list are named we collect them
+    wb.number <- length(w.band) # number of wavebands in list
+    wb.name <- names(w.band) # their names in the list
+    # if no names returned, we fill the vector with "".
+    if (is.null(wb.name)) {
+      wb.name <- character(wb.number)
+    }
 
-    # if the w.band includes 'hinges' we insert them
-    # choose whether to use hinges or not
-    # if the user has specified its value, we leave it alone
-    # but if it was not requested, we decide whether to insert
-    # hinges or not based of the wavelength resolution of the
-    # spectrum. This will produce small errors for high
-    # spectral resolution data, and speed up the calculations
-    # a lot in such cases
+    # hinges
     if (is.null(use.hinges)) {
       use.hinges <- auto_hinges(spct[["w.length"]])
     }
-
     # we collect all hinges and insert them in one go
-    # this may alter a little the returned values
-    # but should be faster
     if (use.hinges) {
       all.hinges <- NULL
       for (wb in w.band) {
-        if (!is.null(wb$hinges) & length(wb[["hinges"]]>0)) {
-          all.hinges <- c(all.hinges, wb[["hinges"]])
-        }
+        all.hinges <- c(all.hinges, wb$hinges)
       }
       if (!is.null(all.hinges)) {
         spct <- insert_spct_hinges(spct, all.hinges)
       }
     }
 
-    # we prepare labels for output
-    wb.name <- names(w.band)
-    no_names_flag <- is.null(wb.name)
-    if (no_names_flag) {
-      wb.name <- character(length(w.band))
-    }
-    #
-    # we iterate through the list of wavebands
+    # We iterate through the list of wavebands collecting the absorbances,
+    # and waveband names.
     absorbance <- numeric(length(w.band))
-    i <- 0
+    i <- 0L
     for (wb in w.band) {
-      i <- i + 1
+      i <- i + 1L
+      # weighting functions are not meaningful
+      if (is_effective(wb)) {
+        warning("Using wavelength range from a weighted waveband object.")
+        wb <- waveband(wl_range(wb))
+      }
       # we get names from wb if needed
-      if (no_names_flag) {
-        if (is_effective(wb)) {
-          warning("Using only wavelength range from a weighted waveband object.")
-          wb.name[i] <- paste("range", as.character(signif(min(wb), 4)),
-                              as.character(signif(max(wb), 4)), sep=".")
+      if (wb.name[i] == "") {
+        if (naming == "short") {
+          wb.name[i] <- labels(wb)[["label"]] # short name
         } else {
-          wb.name[i] <- wb$name
+          wb.name[i] <- labels(wb)[["name"]] # full name
         }
       }
-      # we calculate the average transmittance.
-      absorbance[i] <- integrate_spct(trim_spct(spct, wb, use.hinges=FALSE))
+
+      # we calculate the average absorbance.
+      absorbance[i] <- integrate_spct(trim_spct(spct, wb, use.hinges = FALSE))
     }
 
     if (quantity %in% c("contribution", "contribution.pc")) {
@@ -197,7 +229,8 @@ absorbance_spct <-
                                w.band = NULL,
                                quantity = "total",
                                wb.trim = wb.trim,
-                               use.hinges = use.hinges)
+                               use.hinges = use.hinges,
+                               naming = naming)
       absorbance <- absorbance / total
       if (quantity == "contribution.pc") {
         absorbance <- absorbance * 1e2
@@ -211,14 +244,22 @@ absorbance_spct <-
     } else if (quantity %in% c("average", "mean")) {
       absorbance <- absorbance / sapply(w.band, wl_expanse)
     }
+
     if (length(absorbance) == 0) {
-      absorbance <- NA
+      absorbance <- NA_real_
       names(absorbance) <- "out of range"
+    } else if (naming %in% c("long", "default")) {
+      names(absorbance) <- paste(summary.name, wb.name, sep = "_")
+    } else if (naming == "short") {
+      names(absorbance) <- wb.name
+    } else if (naming != "none") {
+      warning("Argument to 'naming' unrecognized, assuming \"none\".")
     }
-    names(absorbance) <- paste(names(absorbance), wb.name)
+
     attr(absorbance, "Tfr.type") <- getTfrType(spct)
     attr(absorbance, "radiation.unit") <- paste("absorbance", quantity)
-    return(absorbance)
+
+    absorbance
   }
 
 # filter_mspct methods -----------------------------------------------
@@ -235,10 +276,13 @@ absorbance.filter_mspct <-
   function(spct, w.band=NULL,
            quantity = "average",
            wb.trim = getOption("photobiology.waveband.trim", default = TRUE),
-           use.hinges = getOption("photobiology.use.hinges", default = NULL),
+           use.hinges = NULL,
+           naming = "default",
            ...,
            attr2tb = NULL,
-           idx = "spct.idx") {
+           idx = "spct.idx",
+           .parallel = FALSE,
+           .paropts = NULL) {
     z <-
       msdply(
         mspct = spct,
@@ -247,8 +291,11 @@ absorbance.filter_mspct <-
         quantity = quantity,
         wb.trim = wb.trim,
         use.hinges = use.hinges,
+        naming = naming,
         idx = idx,
-        col.names = names(w.band)
+        col.names = names(w.band),
+        .parallel = .parallel,
+        .paropts = .paropts
       )
     add_attr2tb(tb = z,
                 mspct = spct,
@@ -270,10 +317,11 @@ absorbance.filter_mspct <-
 #' @export
 #'
 absorbance.object_mspct <-
-  function(spct, w.band=NULL,
-           quantity="average",
+  function(spct, w.band = NULL,
+           quantity = "average",
            wb.trim = getOption("photobiology.waveband.trim", default = TRUE),
-           use.hinges=getOption("photobiology.use.hinges", default = NULL),
+           use.hinges = NULL,
+           naming = "default",
            ...,
            attr2tb = NULL,
            idx = "spct.idx",
@@ -287,8 +335,9 @@ absorbance.object_mspct <-
         quantity = quantity,
         wb.trim = wb.trim,
         use.hinges = use.hinges,
-        col.names = names(w.band),
+        naming = naming,
         idx = idx,
+        col.names = names(w.band),
         .parallel = .parallel,
         .paropts = .paropts
       )
