@@ -15,6 +15,8 @@
 #' @param use.hinges logical Flag indicating whether to insert "hinges" into the
 #'   spectral data before integration so as to reduce interpolation errors at
 #'   the boundaries of the wavebands.
+#' @param naming character one of "long", "default", "short" or "none". Used to
+#'   select the type of names to assign to returned value.
 #' @param ... other arguments
 #'
 #' @note The \code{use.hinges} parameter controls speed optimization. The
@@ -56,13 +58,17 @@ reflectance.default <- function(spct, w.band, quantity, wb.trim, use.hinges, ...
 #' @export
 #'
 reflectance.reflector_spct <-
-  function(spct, w.band = NULL, quantity = "average",
+  function(spct, w.band = NULL,
+           quantity = "average",
            wb.trim = getOption("photobiology.waveband.trim", default =TRUE),
-           use.hinges=getOption("photobiology.use.hinges", default=NULL), ... ) {
+           use.hinges = NULL,
+           naming = "default",
+           ...) {
     reflectance_spct(spct = spct, w.band = w.band,
                      quantity = quantity,
                      wb.trim = wb.trim,
-                     use.hinges = use.hinges)
+                     use.hinges = use.hinges,
+                     naming = naming)
   }
 
 #' @describeIn reflectance Specialization for object_spct
@@ -70,13 +76,18 @@ reflectance.reflector_spct <-
 #' @export
 #'
 reflectance.object_spct <-
-  function(spct, w.band = NULL, quantity = "average",
+  function(spct,
+           w.band = NULL,
+           quantity = "average",
            wb.trim = getOption("photobiology.waveband.trim", default =TRUE),
-           use.hinges=getOption("photobiology.use.hinges", default=NULL), ... ) {
+           use.hinges = NULL,
+           naming = "default",
+           ... ) {
     reflectance_spct(spct = spct, w.band = w.band,
                      quantity = quantity,
                      wb.trim = wb.trim,
-                     use.hinges = use.hinges)
+                     use.hinges = use.hinges,
+                     naming = naming)
   }
 
 #' Calculate reflectance from spectral reflectance
@@ -96,24 +107,55 @@ reflectance.object_spct <-
 #' @param use.hinges logical Flag indicating whether to insert "hinges" into the
 #'   spectral data before integration so as to reduce interpolation errors at
 #'   the boundaries of the wavebands.
+#' @param naming character one of "long", "default", "short" or "none". Used to
+#'   select the type of names to assign to returned value.
 #'
 #' @return A single numeric value expressed as a fraction of one
 #' @keywords internal
 #'
 reflectance_spct <-
-  function(spct, w.band, quantity, wb.trim, use.hinges){
+  function(spct,
+           w.band,
+           quantity,
+           wb.trim,
+           use.hinges,
+           naming){
+
+    summary.name <-
+      switch(quantity,
+             total = "Rfr",
+             average = "Rfr(wl)",
+             mean = "Rfr(wl)",
+             contribution = "Rfr/Rfrtot",
+             contribution.pc = "Rfr/Rfrtot[%]",
+             relative = "Rfr/Rfrsum",
+             relative.pc = "Rfr/Rfrsum[%]",
+             stop("Unrecognized 'quantity' : \"", quantity, "\"")
+      )
+
+    # we look for multiple spectra and return with a warning
     num.spectra <- getMultipleWl(spct)
     if (num.spectra != 1) {
       warning("Skipping reflectance calculation as object contains ",
               num.spectra, " spectra")
       return(NA_real_)
     }
+    if (is_normalized(spct)) {
+      warning("The spectral data has been normalized,",
+              "making impossible to calculate reflectance")
+      return(NA_real_)
+    }
+    if (is_scaled(spct)) {
+      warning("Reflectance calculated from rescaled data")
+    }
+
     if (is.object_spct(spct)) {
       spct <- as.reflector_spct(spct)
     }
     spct <- spct[ , c("w.length", "Rfr")]
-    # if the waveband is undefined then use all data
+
     if (length(w.band) == 0) {
+      # whole range of spectrum
       w.band <- waveband(spct)
     }
     if (is.numeric(w.band)) {
@@ -121,93 +163,97 @@ reflectance_spct <-
     }
     if (is.waveband(w.band)) {
       # if the argument is a single w.band, we enclose it in a list
-      # so that the for loop works as expected.This is a bit of a
-      # kludge but let's us avoid treating it as a special case
+      # so that it can be handled below as a normal case.
       w.band <- list(w.band)
     }
+    # we trim the wavebands so that they are within the range of spct
     w.band <- trim_waveband(w.band = w.band, range = spct, trim = wb.trim)
+    # if the elements of the list are named we collect them
+    wb.number <- length(w.band) # number of wavebands in list
+    wb.name <- names(w.band) # their names in the list
+    # if no names returned, we fill the vector with "".
+    if (is.null(wb.name)) {
+      wb.name <- character(wb.number)
+    }
 
-    # if the w.band includes 'hinges' we insert them
-    # choose whether to use hinges or not
-    # if the user has specified its value, we leave it alone
-    # but if it was not requested, we decide whether to insert
-    # hinges or not based of the wavelength resolution of the
-    # spectrum. This will produce small errors for high
-    # spectral resolution data, and speed up the calculations
-    # a lot in such cases
+    # hinges
     if (is.null(use.hinges)) {
       use.hinges <- auto_hinges(spct[["w.length"]])
     }
-
     # we collect all hinges and insert them in one go
-    # this may alter a little the returned values
-    # but should be faster
     if (use.hinges) {
       all.hinges <- NULL
       for (wb in w.band) {
-        if (!is.null(wb$hinges) && length(wb$hinges) > 0) {
-          all.hinges <- c(all.hinges, wb$hinges)
-        }
+        all.hinges <- c(all.hinges, wb$hinges)
       }
       if (!is.null(all.hinges)) {
         spct <- insert_spct_hinges(spct, all.hinges)
       }
     }
 
-    # we prepare labels for output
-    wb.name <- names(w.band)
-    no_names_flag <- is.null(wb.name)
-    if (no_names_flag) {
-      wb.name <- character(length(w.band))
-    }
-   # we iterate through the list of wavebands
+    # We iterate through the list of wavebands collecting the transmittances,
+    # and waveband names.
     reflectance <- numeric(length(w.band))
-    i <- 0
+    i <- 0L
     for (wb in w.band) {
-      i <- i + 1
+      i <- i + 1L
+      # weighting functions are not meaningful
+      if (is_effective(wb)) {
+        warning("Using wavelength range from a weighted waveband object.")
+        wb <- waveband(wl_range(wb))
+      }
       # we get names from wb if needed
-      if (no_names_flag) {
-        if (is_effective(wb)) {
-          warning("Using only wavelength range from a weighted waveband object.")
-          wb.name[i] <- paste("range",
-                              as.character(signif(min(wb), 4)),
-                              as.character(signif(max(wb), 4)), sep=".")
+      if (wb.name[i] == "") {
+        if (naming == "short") {
+          wb.name[i] <- labels(wb)[["label"]] # short name
         } else {
-          wb.name[i] <- wb$name
+          wb.name[i] <- labels(wb)[["name"]] # full name
         }
       }
-      # we calculate the average reflectance.
+
+      # we calculate the average reflectance
       reflectance[i] <- integrate_spct(trim_spct(spct, wb, use.hinges = FALSE))
     }
 
-   if (quantity %in% c("contribution", "contribution.pc")) {
-     total <- reflectance_spct(spct, w.band = NULL, wb.trim = wb.trim,
-                                quantity = "total", use.hinges = use.hinges)
-     reflectance <- reflectance / total
-     if (quantity == "contribution.pc") {
-       reflectance <- reflectance * 1e2
-     }
-   } else if (quantity %in% c("relative", "relative.pc")) {
-     total <- sum(reflectance)
-     reflectance <- reflectance / total
-     if (quantity == "relative.pc") {
-       reflectance <- reflectance * 1e2
-     }
-   } else if (quantity %in% c("average", "mean")) {
-     reflectance <- reflectance / sapply(w.band, wl_expanse)
-   } else if (quantity == "total") {
-   } else if (quantity != "total") {
-     warning("'quantity '", quantity, "' is invalid, returning 'total' instead")
-     quantity <- "total"
-   }
-   if (length(reflectance) == 0) {
-     reflectance <- NA
-     names(reflectance) <- "off range"
-   }
-   names(reflectance) <- paste(names(reflectance), wb.name)
-   attr(reflectance, "Rfr.type") <- getRfrType(spct)
-   attr(reflectance, "radiation.unit") <- paste("reflectance", quantity)
-   return(reflectance)
+    if (quantity %in% c("contribution", "contribution.pc")) {
+      total <- reflectance_spct(spct,
+                                w.band = NULL,
+                                wb.trim = wb.trim,
+                                quantity = "total",
+                                use.hinges = use.hinges,
+                                naming = naming)
+      reflectance <- reflectance / total
+      if (quantity == "contribution.pc") {
+        reflectance <- reflectance * 1e2
+      }
+    } else if (quantity %in% c("relative", "relative.pc")) {
+      total <- sum(reflectance)
+      reflectance <- reflectance / total
+      if (quantity == "relative.pc") {
+        reflectance <- reflectance * 1e2
+      }
+    } else if (quantity %in% c("average", "mean")) {
+      reflectance <- reflectance / sapply(w.band, wl_expanse)
+    } else if (quantity == "total") {
+    } else if (quantity != "total") {
+      warning("'quantity '", quantity, "' is invalid, returning 'total' instead")
+      quantity <- "total"
+    }
+
+    if (length(reflectance) == 0) {
+      reflectance <- NA_real_
+      names(reflectance) <- "out of range"
+    } else if (naming %in% c("long", "default")) {
+      names(reflectance) <- paste(summary.name, wb.name, sep = "_")
+    } else if (naming == "short") {
+      names(reflectance) <- wb.name
+    } else if (naming != "none") {
+      warning("Argument to 'naming' unrecognized, assuming \"none\".")
+    }
+
+    attr(reflectance, "Rfr.type") <- getRfrType(spct)
+    attr(reflectance, "radiation.unit") <- paste("reflectance", quantity)
+    reflectance
   }
 
 # reflector_mspct methods -----------------------------------------------
@@ -231,7 +277,8 @@ reflectance.reflector_mspct <-
   function(spct, w.band = NULL,
            quantity = "average",
            wb.trim = getOption("photobiology.waveband.trim", default = TRUE),
-           use.hinges = getOption("photobiology.use.hinges", default = NULL),
+           use.hinges = NULL,
+           naming = "default",
            ...,
            attr2tb = NULL,
            idx = "spct.idx",
@@ -245,6 +292,7 @@ reflectance.reflector_mspct <-
         quantity = quantity,
         wb.trim = wb.trim,
         use.hinges = use.hinges,
+        naming = naming,
         idx = idx,
         col.names = names(w.band),
         .parallel = .parallel,
@@ -266,7 +314,8 @@ reflectance.object_mspct <-
   function(spct, w.band = NULL,
            quantity = "average",
            wb.trim = getOption("photobiology.waveband.trim", default = TRUE),
-           use.hinges= getOption("photobiology.use.hinges", default = NULL),
+           use.hinges = NULL,
+           naming = "default",
            ...,
            attr2tb = NULL,
            idx = "spct.idx",
@@ -280,6 +329,7 @@ reflectance.object_mspct <-
         quantity = quantity,
         wb.trim = wb.trim,
         use.hinges = use.hinges,
+        naming = naming,
         idx = idx,
         col.names = names(w.band),
         .parallel = .parallel,
